seed=1
nrep=12

mkdir -p data_${seed}
cd data_$seed

cat > in.quench <<EOF

#########################################################################
### Melt and quench of amorphous silicon
#########################################################################

variable     T_melt     equal  6000.            # [K]  -- Temperature
variable     T_eq       equal  300.             # [K]  -- Equilibrium Temperature
variable     dt         equal  0.0005            # [ps] -- MD time step

variable     eqthermo_print_interval  equal 500 # [timesteps]
variable     eqtraj_print_interval    equal 100 # [timesteps]

#######################################
### Output style
#######################################

units        metal
atom_style   atomic

#######################################
###Read data
#######################################

read_data           ../../Si.data
replicate           $nrep $nrep $nrep

mass                1 28.05

#######################################
### Pair style
#######################################

pair_style      tersoff
pair_coeff      * *  ../../Si.tersoff Si

timestep        \${dt}

#########################################################################
### Simulation:  melt and quench
#########################################################################

dump                DUMP_MELT all custom \${eqtraj_print_interval} Si-quench.lammpstrj id type x y z
dump_modify         DUMP_MELT element 14
thermo	            \${eqthermo_print_interval}
thermo_style        custom step time temp pe ke etotal press enthalpy vol

# change glass
velocity            all create \${T_melt} $seed mom yes rot yes

fix                 NVE all nve
run                 200000
unfix               NVE

# quench 
fix                 NPT_QUENCH all npt temp \${T_melt} \${T_eq} \$(100.0*dt) iso 0.0 0.0 \$(1000.0*dt)
run                 44000000
unfix               NPT_QUENCH

# Equilibrate
fix                 NVE all nve
run                 20000000
unfix               NVE

write_data          Si-quench.init nocoeff nofix
write_restart       Si-quench.rst

EOF

cat > in.dyn <<EOF

#########################################################################
### Compute the interatomic force constant matrices of amorphous silicon
#########################################################################

#######################################
### Output style
#######################################

units        metal
atom_style   atomic

atom_modify map yes

#######################################
### Read data
#######################################

read_data Si-quench.init 
mass 1 28.05

#######################################
### Pair style
#######################################

pair_style 	        tersoff
pair_coeff          * *  ../../Si.tersoff Si

#######################################
### Minimize
#######################################

neighbor            0.3 bin
neigh_modify        delay 10

thermo              50

min_style           cg
minimize            0.0 1.0e-10 1000000 1000000

write_data          Si-relaxed.init nocoeff nofix
write_restart       Si-relaxed.rst

#######################################
### Compute IFCs
#######################################

print               'calculating dynmat'
dynamical_matrix    all eskm 1e-06 file Dyn.form binary no
print               'uncomment next line to compute third_order'
#third_order         all eskm 1e-06 file THIRD binary no fold yes

EOF

cat > submit.job <<EOF
#!/bin/bash
#LOAD NECESSARY MODULES FOR LAMMPS
LMP=/path/to/lammps

mpirun -np 96 \$LMP -i in.quench  > quench.lmp
mpirun -np 96 \$LMP -i in.dyn  > dyn.lmp
python3 create_final.py

EOF

cat > create_final.py <<EOF

from ase.build import sort
from ase.io import read,write
atoms=read('Si-relaxed.init', format = 'lammps-data', style = 'atomic', Z_of_type = {1:14})
atoms.pbc = True
sorted_atoms = sort(atoms, tags = atoms.arrays['id'])
write('replicated_atoms.xyz', sorted_atoms)
print(sorted_atoms)

EOF

cd ..
