# Example: amorphous silica 
# Computes: Quasi Harmonic Green Kubo (QHGK) thermal conductivity for amorphous silica (192 atoms)
# Uses: LAMMPS
# External files: forcefields/Si.tersoff

# Import necessary packages

from ase.io import read
from kaldo.conductivity import Conductivity
from kaldo.forceconstants import ForceConstants
from kaldo.phonons import Phonons
import numpy as np
import json
from scipy.interpolate import InterpolatedUnivariateSpline
### Set up force constant objects via interface to LAMMPS ####

# Replicate the unit cell 'nrep'=1 time
nrep = 1
N=4
supercell = np.array([nrep, nrep, nrep])
for T in [100,200,300,400,500]:
    for dr in [1]:
            
        # Load in computed 2nd, 3rd IFCs from LAMMPS outputs
        forceconstants = ForceConstants.from_folder(folder='N{}/{}/'.format(N,dr),supercell=supercell,format='numpy',only_second=True)
        # Configure phonon object
        # 'is_classic': specify if the system is classic, True for classical and False for quantum
        # 'temperature: temperature (Kelvin) at which simulation is performed
        # 'folder': name of folder containing phonon property and thermal conductivity calculations
        # 'storage': Format to storage phonon properties ('formatted' for ASCII format data, 'numpy' 
        #            for python numpy array and 'memory' for quick calculations, no data stored)
        
        phonons_config = {'is_classic': False, 
                          'temperature': T, #'temperature'=300K
                          'folder': 'ald_{}_{}/'.format(N,dr),
                           'third_bandwidth':0.5/4.135, # 0.5 eV is used here.
                           'broadening_shape':'triangle',
                           'storage': 'numpy'}
        
        # Set up phonon object by passing in configuration details and the forceconstants object computed above
        phonons = Phonons(forceconstants=forceconstants, **phonons_config)
        freq=phonons.frequency

        #load spline of anharmonic bandwidths 
        with open(f'anharmonic_linewidths/gamma_{T}K.json', 'r') as f:
            spl_dict = json.load(f)
        spl = InterpolatedUnivariateSpline._from_tck((np.array(spl_dict['knots']), np.array(spl_dict['coeffs']), spl_dict['degree']))
        omega=2*np.pi*freq.flatten()
        gamma=spl(omega) #Beware: spline fitted over angular frequencies

        gamma=gamma.reshape(freq.shape)

        #qhgk thermal conductivity
        qhgk_cond = Conductivity(phonons=phonons, method='qhgk', storage='numpy')
        qhgk_cond.diffusivity_bandwidth = gamma*0.5
        print('Conductivity from QHGK (W/m-K): %.3f' % (np.mean(np.diag(qhgk_cond.conductivity.sum(axis=0)))))
        print(qhgk_cond.conductivity.sum(axis=0))
